package com.njyunzhi.admin.controller;

import cn.dev33.satoken.util.SaResult;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.njyunzhi.admin.service.FxTenantService;
import com.njyunzhi.common.util.StringUtil;
import com.njyunzhi.framework.accesslimit.AccessLimit;
import com.njyunzhi.framework.log.OpLog;
import com.njyunzhi.repository.BaseController;
import com.njyunzhi.repository.entity.FxTenant;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * 租户表;(fx_tenant)表控制层
 *
 * @author : http://njyunzhi.com
 * @date : 2023-11-15
 */
@Api(tags = "租户表对象功能接口")
@RestController
@RequestMapping("/admin")
public class FxTenantController extends BaseController {

    @Autowired
    private FxTenantService fxTenantService;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @OpLog(module = "租户表", action = "查询单条数据", desc = "ID：{{#id}}")
    @AccessLimit()
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/fxTenant/{id}")
    public SaResult queryById(@ApiParam("对象ID") @PathVariable String id) throws Exception {
        return SaResult.data(fxTenantService.getById(id));
    }

    /**
     * 分页查询
     *
     * @param pageNum  当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @OpLog(module = "租户表", action = "分页列表查询")
    @AccessLimit()
    @ApiOperation("分页查询")
    @GetMapping("/fxTenant")
    public SaResult list(@ApiParam("页码") @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                         @ApiParam("单页数据量") @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                         @ApiParam("状态") @RequestParam(value = "status", required = false) String status,
                         @ApiParam("手机号") @RequestParam(value = "phone", required = false) String phone,
                         @ApiParam("租户名称") @RequestParam(value = "tenantName", required = false) String tenantName,
                         @ApiParam("租户编号") @RequestParam(value = "tenantCode", required = false) String tenantCode,
                         @ApiParam("开始时间") @RequestParam(value = "startTime", required = false) String startTime,
                         @ApiParam("结束时间") @RequestParam(value = "endTime", required = false) String endTime,
                         @ApiParam("正序排列") @RequestParam(value = "sortAsc", required = false) String sortAsc,
                         @ApiParam("倒序排列") @RequestParam(value = "sortDesc", defaultValue = "created_at") String sortDesc) throws Exception {

        IPage<FxTenant> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<FxTenant> queryWrapper = new QueryWrapper<>();
        String tenantId = getTenantId();
//        queryWrapper.ge(StringUtil.isNotEmpty(startTime),"start_time",startTime).
        queryWrapper.eq("tenant_id",tenantId);
        queryWrapper.ge(!StringUtil.isEmpty(startTime), "DATE_FORMAT(start_time,'%Y-%m-%d')", startTime)
                .le(!StringUtil.isEmpty(endTime), "DATE_FORMAT(end_time,'%Y-%m-%d')", endTime);
        queryWrapper.eq(StringUtil.isNotEmpty(status), "status", status);
        queryWrapper.like(StringUtil.isNotEmpty(phone), "phone", phone);
        queryWrapper.like(StringUtil.isNotEmpty(tenantName), "tenant_name", tenantName);
        queryWrapper.like(StringUtil.isNotEmpty(tenantCode), "tenant_code", tenantCode);
        queryWrapper.orderByAsc(StringUtil.isNotEmpty(sortAsc), StringUtil.humpToLine(sortAsc));
        queryWrapper.orderByDesc(StringUtil.isNotEmpty(sortDesc), StringUtil.humpToLine(sortDesc));
        IPage<FxTenant> result = fxTenantService.page(pg, queryWrapper);

        return SaResult.data(result);
    }

    /**
     * 新增数据
     *
     * @param fxTenant 实例对象
     * @return 实例对象
     */
    @OpLog(module = "租户表", action = "新增数据")
    @AccessLimit()
    @ApiOperation("新增数据")
    @PostMapping("/fxTenant")
    public SaResult add(@ApiParam("对象实体") @Validated @RequestBody FxTenant fxTenant) throws Exception {
        String tenantId = getTenantId();
        fxTenant.setTenantId(tenantId);
        fxTenantService.save(fxTenant);
        return SaResult.data(fxTenant);
    }

    /**
     * 更新数据
     *
     * @param fxTenant 实例对象
     * @return 实例对象
     */
    @OpLog(module = "租户表", action = "更新数据")
    @AccessLimit()
    @ApiOperation("更新数据")
    @PutMapping("/fxTenant/{id}")
    public SaResult edit(@ApiParam("对象实体") @Validated @RequestBody FxTenant fxTenant,
                         @ApiParam("对象ID") @PathVariable String id) throws Exception {
        fxTenantService.updateById(fxTenant);
        return SaResult.data(fxTenant);
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @OpLog(module = "租户表", action = "删除数据", desc = "ID：{{#id}}")
    @AccessLimit()
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/fxTenant/{id}")
    public SaResult deleteById(@ApiParam("对象ID") @PathVariable String id) {
        fxTenantService.removeById(id);
        return SaResult.data("success");
    }
}