package com.njyunzhi.admin.controller;

import cn.dev33.satoken.stp.StpUtil;
import cn.dev33.satoken.util.SaResult;
import com.njyunzhi.admin.dto.ChangePasswordDTO;
import com.njyunzhi.admin.dto.LoginDTO;
import com.njyunzhi.admin.service.FxTenantService;
import com.njyunzhi.admin.service.SysLoginService;
import com.njyunzhi.common.util.StringUtil;
import com.njyunzhi.repository.BaseController;
import com.njyunzhi.repository.entity.FxTenant;
import com.njyunzhi.repository.entity.SysUser;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.Map;

/**
 * 登录信息表;(sys_login)表控制层
 *
 * @author : http://njyunzhi.com
 * @date : 2023-10-25
 */
@Api(tags = "登录信息表对象功能接口")
@RestController
@RequestMapping("/admin")
public class SysLoginController extends BaseController {

    @Autowired
    private SysLoginService sysLoginService;
    @Autowired
    private FxTenantService fxTenantService;

    @PostMapping("/login")
    @ApiOperation(value = "后台登录", notes = "后台登录", httpMethod = "POST", response = SaResult.class)
    public SaResult login(@ApiParam("登录参数") @RequestBody LoginDTO loginParm) throws Exception {
        FxTenant fxTenant = fxTenantService.getById(loginParm.getTenantId());
        if (fxTenant == null) {
            throw new Exception("沒有此租戶");
        }
        if (fxTenant.getStatus().equals(0)) {
            throw new Exception("未激活");

        }

        if (fxTenant.getStatus().equals(2)) {
            throw new Exception("停用");

        }


        if (StringUtil.isEmpty(loginParm.getTenantId())) {
            throw new Exception("所属租户不能为空");
        }

        if (StringUtil.isEmpty(loginParm.getLoginName()) || StringUtil.isEmpty(loginParm.getPassword())) {
            return SaResult.error("登录用户或者密码不能为空");
        }

        SysUser sysUser = sysLoginService.login(loginParm,fxTenant.getTenantId());

        StpUtil.login(sysUser.getUserId());
        String tokenValue = StpUtil.getTokenValue();

        Map<String, Object> result = new HashMap<>();
        result.put("user", sysUser);
        result.put("token", tokenValue);

        return SaResult.data(result);
    }

    @PostMapping("/logout")
    @ApiOperation(value = "登出", notes = "登出", httpMethod = "POST", response = SaResult.class)
    public SaResult logout() throws Exception {
        SysUser sysUser = (SysUser) currentUser();
        StpUtil.logout(sysUser.getUserId());
        return SaResult.ok();
    }


    @PutMapping("/change-password")
    @ApiOperation(value = "修改密码", notes = "修改密码", httpMethod = "PUT", response = SaResult.class)
    public SaResult changePassword(@ApiParam("修改密码参数") @RequestBody ChangePasswordDTO param) throws Exception {
        if (StringUtil.isEmpty(param.getOriginPassword()) || StringUtil.isEmpty(param.getNewPassword())) {
            return SaResult.error("原始密码或新密码不能为空");
        }

        SysUser sysUser = (SysUser) currentUser();

        boolean isOk = sysLoginService.changePassword(sysUser, param);
        if (!isOk) {
            SaResult.error("修改失败, 请重试");
        }

        return SaResult.ok("密码修改成功");
    }

}