package com.njyunzhi.admin.controller;

import cn.dev33.satoken.util.SaResult;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.njyunzhi.admin.service.SysRoleService;
import com.njyunzhi.common.util.StringUtil;
import com.njyunzhi.framework.accesslimit.AccessLimit;
import com.njyunzhi.framework.log.OpLog;
import com.njyunzhi.repository.BaseController;
import com.njyunzhi.repository.entity.SysRole;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * 系统角色;(sys_role)表控制层
 *
 * @author : http://njyunzhi.com
 * @date : 2023-10-25
 */
@Api(tags = "系统角色对象功能接口")
@RestController
@RequestMapping("/admin")
public class SysRoleController extends BaseController {

    @Autowired
    private SysRoleService sysRoleService;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @OpLog(module = "系统角色", action = "查询单条数据", desc = "ID：{{#id}}")
    @AccessLimit()
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/sysRole/{id}")
    public SaResult queryById(@ApiParam("对象ID") @PathVariable String id) throws Exception {
        return SaResult.data(sysRoleService.getById(id));
    }

    /**
     * 分页查询
     *
     * @param pageNum  当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @OpLog(module = "系统角色", action = "分页列表查询")
    @AccessLimit()
    @ApiOperation("分页查询")
    @GetMapping("/sysRole")
    public SaResult list(@ApiParam("页码") @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                         @ApiParam("单页数据量") @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                         @ApiParam("正序排列") @RequestParam(value = "sortAsc", required = false) String sortAsc,
                         @ApiParam("倒序排列") @RequestParam(value = "sortDesc", defaultValue = "created_at") String sortDesc) throws Exception {
        String tenantId = getTenantId();
        IPage<SysRole> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<SysRole> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("tenant_id", tenantId);
        queryWrapper.orderByAsc(StringUtil.isNotEmpty(sortAsc), StringUtil.humpToLine(sortAsc));
        queryWrapper.orderByDesc(StringUtil.isNotEmpty(sortDesc), StringUtil.humpToLine(sortDesc));
        IPage<SysRole> result = sysRoleService.page(pg, queryWrapper);

        return SaResult.data(result);
    }

    /**
     * 新增数据
     *
     * @param sysRole 实例对象
     * @return 实例对象
     */
    @OpLog(module = "系统角色", action = "新增数据")
    @AccessLimit()
    @ApiOperation("新增数据")
    @PostMapping("/sysRole")
    public SaResult add(@ApiParam("对象实体") @Validated @RequestBody SysRole sysRole) throws Exception {
        String tenantId = getTenantId();
        sysRole.setTenantId(tenantId);
        sysRoleService.save(sysRole);
        return SaResult.data(sysRole);
    }

    /**
     * 更新数据
     *
     * @param sysRole 实例对象
     * @return 实例对象
     */
    @OpLog(module = "系统角色", action = "更新数据")
    @AccessLimit()
    @ApiOperation("更新数据")
    @PutMapping("/sysRole/{id}")
    public SaResult edit(@ApiParam("对象实体") @Validated @RequestBody SysRole sysRole,
                         @ApiParam("对象ID") @PathVariable String id) throws Exception {
        sysRole.setRoleId(id);
        sysRoleService.updateById(sysRole);
        return SaResult.data(sysRole);
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @OpLog(module = "系统角色", action = "删除数据", desc = "ID：{{#id}}")
    @AccessLimit()
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/sysRole/{id}")
    public SaResult deleteById(@ApiParam("对象ID") @PathVariable String id) {
        sysRoleService.removeById(id);
        return SaResult.data("success");
    }
}