package com.njyunzhi.admin.controller;

import cn.dev33.satoken.util.SaResult;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.njyunzhi.admin.service.SysRoleResourceService;
import com.njyunzhi.common.util.StringUtil;
import com.njyunzhi.framework.accesslimit.AccessLimit;
import com.njyunzhi.framework.log.OpLog;
import com.njyunzhi.repository.BaseController;
import com.njyunzhi.repository.entity.SysRoleResource;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

 /**
 * 角色资源;(sys_role_resource)表控制层
 * @author : http://njyunzhi.com
 * @date : 2023-10-25
 */
@Api(tags = "角色资源对象功能接口")
@RestController
@RequestMapping("/admin")
public class SysRoleResourceController extends BaseController {
    
    @Autowired
    private SysRoleResourceService sysRoleResourceService;
    
    /** 
     * 通过ID查询单条数据 
     *
     * @param id 主键
     * @return 实例对象
     */
    @OpLog(module = "角色资源", action = "查询单条数据", desc = "ID：{{#id}}")
    @AccessLimit()
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/sysRoleResource/{id}")
    public SaResult queryById(@ApiParam("对象ID") @PathVariable String id) throws Exception {
        return SaResult.data(sysRoleResourceService.getById(id));
    }
    
    /** 
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @OpLog(module = "角色资源", action = "分页列表查询")
    @AccessLimit()
    @ApiOperation("分页查询")
    @GetMapping("/sysRoleResource")
    public SaResult list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                            @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                            @ApiParam("正序排列") @RequestParam(value ="sortAsc", required = false) String sortAsc,
                         @ApiParam("倒序排列") @RequestParam(value ="sortDesc", defaultValue = "created_at") String sortDesc) throws Exception {
        
        IPage<SysRoleResource> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<SysRoleResource> queryWrapper = new QueryWrapper<>();
        queryWrapper.orderByAsc(StringUtil.isNotEmpty(sortAsc), StringUtil.humpToLine(sortAsc));
        queryWrapper.orderByDesc(StringUtil.isNotEmpty(sortDesc), StringUtil.humpToLine(sortDesc));
        IPage<SysRoleResource> result = sysRoleResourceService.page(pg, queryWrapper);
        
        return SaResult.data(result);
    }
    
    /** 
     * 新增数据
     *
     * @param sysRoleResource 实例对象
     * @return 实例对象
     */
    @OpLog(module = "角色资源", action = "新增数据")
    @AccessLimit()
    @ApiOperation("新增数据")
    @PostMapping("/sysRoleResource")
    public SaResult add(@ApiParam("对象实体") @Validated @RequestBody SysRoleResource sysRoleResource) throws Exception {
        sysRoleResourceService.save(sysRoleResource);
        return SaResult.data(sysRoleResource);
    }
    
    /** 
     * 更新数据
     *
     * @param sysRoleResource 实例对象
     * @return 实例对象
     */
    @OpLog(module = "角色资源", action = "更新数据")
    @AccessLimit()
    @ApiOperation("更新数据")
    @PutMapping("/sysRoleResource/{id}")
    public SaResult edit(@ApiParam("对象实体") @Validated @RequestBody SysRoleResource sysRoleResource,
                            @ApiParam("对象ID") @PathVariable String id ) throws Exception {
        sysRoleResourceService.updateById(sysRoleResource);
        return SaResult.data(sysRoleResource);
    }
    
    /** 
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @OpLog(module = "角色资源", action = "删除数据", desc = "ID：{{#id}}")
    @AccessLimit()
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/sysRoleResource/{id}")
    public SaResult deleteById(@ApiParam("对象ID") @PathVariable String id){
        sysRoleResourceService.removeById(id);
        return SaResult.data("success");
    }


     /**
      * 授权资源
      *
      * @param roleId            角色ID
      * @param roleResourcesList 授权列表
      * @return 实例对象
      */
     @OpLog(module = "角色管理", action = "授权资源")
     @ApiOperation("授权资源, 包含编辑")
     @PostMapping("/role/{roleId}/resources")
     public SaResult authResource(@ApiParam("角色ID") @PathVariable String roleId,
                                  @ApiParam("授权列表") @RequestBody List<SysRoleResource> roleResourcesList) throws Exception {
         if (null == roleResourcesList) {
             return SaResult.error("未找到授权对象");
         }

         sysRoleResourceService.mergeData(roleId, roleResourcesList);
         return SaResult.data(roleResourcesList);
     }

     /**
      * 获取授权资源
      *
      * @param roleId            角色ID
      * @return 实例对象
      */
     @OpLog(module = "角色管理", action = "获取授权资源")
     @ApiOperation("获取授权资源")
     @GetMapping("/role/{roleId}/resources")
     public SaResult getAuthResource(@ApiParam("角色ID") @PathVariable String roleId) throws Exception {
         List<SysRoleResource> roleResourcesList = sysRoleResourceService.getListByRole(roleId);
         return SaResult.data(roleResourcesList);
     }




}