package com.njyunzhi.admin.controller;

import cn.dev33.satoken.stp.StpUtil;
import cn.dev33.satoken.util.SaResult;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.njyunzhi.admin.common.Constants;
import com.njyunzhi.admin.dto.ResetPasswordDTO;
import com.njyunzhi.admin.service.*;
import com.njyunzhi.common.util.StringUtil;
import com.njyunzhi.framework.accesslimit.AccessLimit;
import com.njyunzhi.framework.log.OpLog;
import com.njyunzhi.repository.BaseController;
import com.njyunzhi.repository.entity.SysMenu;
import com.njyunzhi.repository.entity.SysRole;
import com.njyunzhi.repository.entity.SysUser;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 用户管理;(sys_user)表控制层
 *
 * @author : http://njyunzhi.com
 * @date : 2023-10-25
 */
@Api(tags = "用户管理对象功能接口")
@RestController
@RequestMapping("/admin")
public class SysUserController extends BaseController {

    @Autowired
    SysUserService sysUserService;

    @Autowired
    SysRoleService sysRoleService;

    @Autowired
    SysUserRoleService sysUserRoleService;

    @Autowired
    SysMenuService sysMenuService;

    @Autowired
    SysLoginService sysLoginService;


    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @OpLog(module = "人员管理", action = "查询详情")
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/sysUser/{id}")
    public SaResult queryById(@ApiParam("对象ID") @PathVariable String id) throws Exception {
        SysUser sysUser = sysUserService.getById(id);
        if (null == sysUser) {
            return SaResult.error("用户不存在");
        }

        List<SysRole> roleList = sysRoleService.getByUser(id);
        sysUser.setRoleList(roleList);

        return SaResult.data(sysUser);
    }

    @AccessLimit()
    @ApiOperation("获取当前用户")
    @GetMapping("/current")
    public SaResult getCurrentUser() throws Exception {
        boolean isLogin = StpUtil.isLogin();
        if (!isLogin) {
            return SaResult.error("请先登录系统");
        }

        Map<String, Object> result = new HashMap<>();
        SysUser sysUser = (SysUser) currentUser();
        List<SysMenu> menuList = sysUserService.getMneusByUser(sysUser);
//         List<SysMenuButton> buttonList = sysUserService.getMenuButtonsByUser(sysUser);

        result.put("user", sysUser);
        result.put("menuList", menuList);
//         result.put("buttonList", buttonList);
        return SaResult.data(result);
    }

    /**
     * 分页查询
     *
     * @param pageNum  当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @OpLog(module = "人员管理", action = "查询列表")
    @ApiOperation("分页查询")
    @GetMapping("/sysUser")
    public SaResult list(@ApiParam("页码") @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                         @ApiParam("单页数据量") @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                         @ApiParam("姓名") @RequestParam(value = "userName", required = false) String userName,
                         @ApiParam("机构") @RequestParam(value = "deptId", required = false) String deptId,
                         @ApiParam("展馆") @RequestParam(value = "hallUniqueId", required = false) String hallUniqueId,
                         @ApiParam("岗位ID") @RequestParam(value = "positionId", required = false) String positionId,
                         @ApiParam("手机号") @RequestParam(value = "phone", required = false) String phone,
                         @ApiParam("身份") @RequestParam(value = "identityType", required = false) Integer identityType) throws Exception {
        String tenantId = getTenantId();
        IPage<SysUser> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<SysUser> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("tenant_id", tenantId);
        queryWrapper.like(!StringUtil.isEmpty(userName), "user_name", userName);
        queryWrapper.eq(!StringUtil.isEmpty(deptId), "dept_id", deptId);
        queryWrapper.eq(!StringUtil.isEmpty(hallUniqueId), "hall_unique_id", hallUniqueId);
        queryWrapper.eq(!StringUtil.isEmpty(positionId), "position_id", positionId);
        queryWrapper.like(!StringUtil.isEmpty(phone), "phone", phone);
        queryWrapper.gt(null != identityType, " (identity_type & " + identityType + ") ", 0);
        queryWrapper.ne("user_id", Constants.ROOT_ID);
        queryWrapper.orderByDesc("created_at");
        IPage<SysUser> result = sysUserService.page(pg, queryWrapper);

        return SaResult.data(result);
    }

    /**
     * 新增数据
     *
     * @param sysUser 实例对象
     * @return 实例对象
     */
    @OpLog(module = "人员管理", action = "新增数据")
    @ApiOperation("新增数据")
    @PostMapping("/sysUser")
    public SaResult add(@ApiParam("对象实体") @Validated @RequestBody SysUser sysUser) throws Exception {
        String tenantId = getTenantId();

        if (null == sysUser.getUserId()) {
            long count = sysUserService.countBy("phone", sysUser.getPhone());
            if (count > 0) {
                return SaResult.error("手机号码已存在");
            }
        }
        sysUser.setTenantId(tenantId);
        sysUserService.mergeData(sysUser);

        return SaResult.data(sysUserService.getById(sysUser.getUserId()));
    }


    /**
     * 更新状态
     *
     * @param id 实例ID
     * @return 实例对象
     */
    @OpLog(module = "人员管理", action = "更新状态")
    @ApiOperation("更新状态")
    @PutMapping("/sysUser/{id}/status")
    public SaResult edit(@ApiParam("对象ID") @PathVariable String id,
                         @ApiParam("页码") @RequestParam(value = "status") Integer status) throws Exception {

        SysUser sysUser = sysUserService.getById(id);
        sysUser.setStatus(status);

        sysUserService.updateById(sysUser);

        return SaResult.data(sysUser);
    }


    /**
     * 重置密码
     *
     * @param id 实例ID
     * @return 实例对象
     */
    @OpLog(module = "人员管理", action = "重置密码", desc = "人员ID: {{#id}}")
    @ApiOperation("重置密码")
    @PutMapping("/sysUser/{id}/password")
    public SaResult resetPassword(@ApiParam("对象ID") @PathVariable String id,
                                  @ApiParam("页码") @Validated @RequestBody ResetPasswordDTO newPassword) throws Exception {

        SysUser sysUser = sysUserService.getById(id);
        if (null == sysUser) {
            return SaResult.error("人员不存在");
        }

        sysLoginService.resetPassword(sysUser, newPassword);
        return SaResult.data(sysUser);
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @OpLog(module = "人员管理", action = "删除数据")
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/sysUser/{id}")
    public SaResult deleteById(@ApiParam("对象ID") @PathVariable String id) {
        SysUser sysUser = sysUserService.getById(id);
        if (null != sysUser && sysUser.getIsAdmin() == 1) {
            return SaResult.error("不能对管理员进行此操作");
        }

        sysUserService.removeById(id);

        // 授权角色
        sysUserRoleService.removeByMap(new HashMap<String, Object>() {{
            put("user_id", id);
        }});

        return SaResult.ok("success");
    }
}