package com.njyunzhi.admin.controller;

import cn.dev33.satoken.util.SaResult;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.njyunzhi.admin.service.SysUserRoleService;
import com.njyunzhi.common.util.StringUtil;
import com.njyunzhi.framework.accesslimit.AccessLimit;
import com.njyunzhi.framework.log.OpLog;
import com.njyunzhi.repository.BaseController;
import com.njyunzhi.repository.entity.SysUserRole;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

 /**
 * 角色授权;(sys_user_role)表控制层
 * @author : http://njyunzhi.com
 * @date : 2023-10-26
 */
@Api(tags = "角色授权对象功能接口")
@RestController
@RequestMapping("/admin")
public class SysUserRoleController extends BaseController {
    
    @Autowired
    private SysUserRoleService sysUserRoleService;
    
    /** 
     * 通过ID查询单条数据 
     *
     * @param id 主键
     * @return 实例对象
     */
    @OpLog(module = "角色授权", action = "查询单条数据", desc = "ID：{{#id}}")
    @AccessLimit()
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/sysUserRole/{id}")
    public SaResult queryById(@ApiParam("对象ID") @PathVariable String id) throws Exception {
        return SaResult.data(sysUserRoleService.getById(id));
    }
    
    /** 
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @OpLog(module = "角色授权", action = "分页列表查询")
    @AccessLimit()
    @ApiOperation("分页查询")
    @GetMapping("/sysUserRole")
    public SaResult list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                            @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                            @ApiParam("正序排列") @RequestParam(value ="sortAsc", required = false) String sortAsc,
                         @ApiParam("倒序排列") @RequestParam(value ="sortDesc", defaultValue = "created_at") String sortDesc) throws Exception {
        
        IPage<SysUserRole> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<SysUserRole> queryWrapper = new QueryWrapper<>();
        queryWrapper.orderByAsc(StringUtil.isNotEmpty(sortAsc), StringUtil.humpToLine(sortAsc));
        queryWrapper.orderByDesc(StringUtil.isNotEmpty(sortDesc), StringUtil.humpToLine(sortDesc));
        IPage<SysUserRole> result = sysUserRoleService.page(pg, queryWrapper);
        
        return SaResult.data(result);
    }
    
    /** 
     * 新增数据
     *
     * @param sysUserRole 实例对象
     * @return 实例对象
     */
    @OpLog(module = "角色授权", action = "新增数据")
    @AccessLimit()
    @ApiOperation("新增数据")
    @PostMapping("/sysUserRole")
    public SaResult add(@ApiParam("对象实体") @Validated @RequestBody SysUserRole sysUserRole) throws Exception {
        sysUserRoleService.save(sysUserRole);
        return SaResult.data(sysUserRole);
    }
    
    /** 
     * 更新数据
     *
     * @param sysUserRole 实例对象
     * @return 实例对象
     */
    @OpLog(module = "角色授权", action = "更新数据")
    @AccessLimit()
    @ApiOperation("更新数据")
    @PutMapping("/sysUserRole/{id}")
    public SaResult edit(@ApiParam("对象实体") @Validated @RequestBody SysUserRole sysUserRole,
                            @ApiParam("对象ID") @PathVariable String id ) throws Exception {
        sysUserRoleService.updateById(sysUserRole);
        return SaResult.data(sysUserRole);
    }
    
    /** 
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @OpLog(module = "角色授权", action = "删除数据", desc = "ID：{{#id}}")
    @AccessLimit()
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/sysUserRole/{id}")
    public SaResult deleteById(@ApiParam("对象ID") @PathVariable String id){
        sysUserRoleService.removeById(id);
        return SaResult.data("success");
    }
}