package com.njyunzhi.admin.controller;

import com.njyunzhi.admin.service.TaPersonService;
import com.njyunzhi.repository.BaseController;
import com.njyunzhi.repository.entity.TaPerson;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.PageRequest;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 人员表;(ta_person)表控制层
 *
 * @author : http://www.chiner.pro
 * @date : 2024-2-26
 */
@Api(tags = "人员表对象功能接口")
@RestController
@RequestMapping("/taPerson")
public class TaPersonController extends BaseController {
    @Autowired
    private TaPersonService taPersonService;

    /**
     * 通过ID查询单条数据
     *
     * @param personId 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("{personid}")
    public ResponseEntity<TaPerson> queryById(String personId) {
        return ResponseEntity.ok(taPersonService.queryById(personId));
    }

    /**
     * 分页查询
     *
     * @param taPerson    筛选条件
     * @param pageRequest 分页对象
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping
    public ResponseEntity<PageImpl<TaPerson>> paginQuery(TaPerson taPerson, PageRequest pageRequest) {
        //1.分页参数
        long current = pageRequest.getPageNumber();
        long size = pageRequest.getPageSize();
        //2.分页查询
        /*把Mybatis的分页对象做封装转换，MP的分页对象上有一些SQL敏感信息，还是通过spring的分页模型来封装数据吧*/
        com.baomidou.mybatisplus.extension.plugins.pagination.Page<TaPerson> pageResult = taPersonService.paginQuery(taPerson, current, size);
        //3. 分页结果组装
        List<TaPerson> dataList = pageResult.getRecords();
        long total = pageResult.getTotal();
        PageImpl<TaPerson> retPage = new PageImpl<TaPerson>(dataList, pageRequest, total);
        return ResponseEntity.ok(retPage);
    }

    /**
     * 新增数据
     *
     * @param taPerson 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping
    public ResponseEntity<TaPerson> add(TaPerson taPerson) {
        return ResponseEntity.ok(taPersonService.insert(taPerson));
    }

    /**
     * 更新数据
     *
     * @param taPerson 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping
    public ResponseEntity<TaPerson> edit(TaPerson taPerson) {
        return ResponseEntity.ok(taPersonService.update(taPerson));
    }

    /**
     * 通过主键删除数据
     *
     * @param personId 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping
    public ResponseEntity<Boolean> deleteById(String personId) {
        return ResponseEntity.ok(taPersonService.deleteById(personId));
    }
}