package com.njyunzhi.admin.service.impl;

import com.njyunzhi.admin.common.Constants;
import com.njyunzhi.admin.dto.ChangePasswordDTO;
import com.njyunzhi.admin.dto.LoginDTO;
import com.njyunzhi.admin.dto.ResetPasswordDTO;
import com.njyunzhi.admin.service.SysLoginService;
import com.njyunzhi.common.util.EncryptUtil;
import com.njyunzhi.common.util.StringUtil;
import com.njyunzhi.repository.BaseServiceImpl;
import com.njyunzhi.repository.entity.SysLogin;
import com.njyunzhi.repository.entity.SysUser;
import com.njyunzhi.repository.mapper.SysLoginMapper;
import com.njyunzhi.repository.mapper.SysUserMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 登录信息表;(sys_login)表服务实现类
 *
 * @author : http://www.chiner.pro
 * @date : 2023-10-25
 */
@Service
public class SysLoginServiceImpl extends BaseServiceImpl<SysLoginMapper, SysLogin> implements SysLoginService {

    @Autowired
    SysUserMapper sysUserMapper;

    private boolean checkPassword(String src, String targ, String salt) {
        String newPass = EncryptUtil.md5(src, salt);
        return targ.equals(newPass);
    }

    @Override
    public SysUser login(LoginDTO loginParm, String tenantId) throws Exception {

        SysLogin sysLogin = baseMapper.getInfoBy(loginParm.getLoginType(), loginParm.getLoginName());
        if (null == sysLogin) {
            throw new Exception("用户名或者密码不正确");
        }

        String userId = sysLogin.getUserId();
        if (StringUtil.isEmpty(userId)) {
            throw new Exception("用户名或者密码不正确");
        }

        boolean isRight = checkPassword(loginParm.getPassword(), sysLogin.getPassword(), userId);
        if (!isRight) {
            throw new Exception("用户名或者密码不正确");
        }

        SysUser user = sysUserMapper.selectById(userId);
        if (null == user) {
            throw new Exception("用户名或者密码不正确");
        }

        if (Constants.STATUS_NORMAL != user.getStatus()) {
            throw new Exception("用户状态异常, 请联系管理员");
        }

        if (user.getTenantId() == null) {
            throw new Exception("该账户的租户信息异常");
        }
        if (!user.getTenantId().equals(tenantId)) {
            throw new Exception("该账户的租户信息错误");

        }

        return user;
    }

    @Override
    public boolean changePassword(SysUser user, ChangePasswordDTO param) throws Exception {
        String passwordEncrypted = EncryptUtil.md5(param.getOriginPassword(), user.getUserId());
        Long cnt = baseMapper.countByUserAndPassword(user.getUserId(), passwordEncrypted);

        if (null == cnt || cnt < 1) {
            throw new Exception("原始密码不正确");
        }

        String newPassword = EncryptUtil.md5(param.getNewPassword(), user.getUserId());
        return baseMapper.updateUserPassword(user.getUserId(), newPassword) > 0;
    }

    @Override
    public void resetPassword(SysUser sysUser, ResetPasswordDTO newPassword) {
        String newPasswordStr = EncryptUtil.md5(newPassword.getPassword(), sysUser.getUserId());
        baseMapper.updateUserPassword(sysUser.getUserId(), newPasswordStr);
    }
}