package com.njyunzhi.admin.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.njyunzhi.admin.common.Constants;
import com.njyunzhi.admin.service.SysUserService;
import com.njyunzhi.common.util.EncryptUtil;
import com.njyunzhi.repository.BaseServiceImpl;
import com.njyunzhi.repository.entity.*;
import com.njyunzhi.repository.mapper.SysLoginMapper;
import com.njyunzhi.repository.mapper.SysUserMapper;
import com.njyunzhi.repository.mapper.SysUserRoleMapper;
import com.njyunzhi.repository.repo.SysMenuRepo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

/**
 * 用户管理;(sys_user)表服务实现类
 *
 * @author : http://www.chiner.pro
 * @date : 2023-10-25
 */
@Service
public class SysUserServiceImpl extends BaseServiceImpl<SysUserMapper, SysUser> implements SysUserService {

    @Autowired
    SysUserRoleMapper sysUserRoleMapper;

    @Autowired
    SysLoginMapper sysLoginMapper;

    @Autowired
    SysMenuRepo sysMenuRepo;

    @Override
    public void mergeData(SysUser sysUser) throws Exception {
        //
        SysUser origin = getById(sysUser.getUserId());
        LocalDateTime now = LocalDateTime.now();

        // 用户表
        if (null == origin) {
            if (null == sysUser.getStatus()) {
                sysUser.setStatus(Constants.STATUS_NORMAL);
            }
            save(sysUser);
        } else {
            sysUser.setStatus(Constants.STATUS_NORMAL);
            updateById(sysUser);
        }

        // 登录账号
        SysLogin sysLogin = sysLoginMapper.getInfoBy(Constants.LOGIN_TYPE_ACCOUNT, sysUser.getPhone());
        if (null == sysLogin) {
            sysLogin = new SysLogin();
            sysLogin.setUserId(sysUser.getUserId());
            sysLogin.setLoginType(Constants.LOGIN_TYPE_ACCOUNT);
            sysLogin.setLoginName(sysUser.getPhone());
            sysLogin.setPassword(EncryptUtil.md5(EncryptUtil.md5("123456"), sysUser.getUserId()));
            sysLogin.setStatus(Constants.STATUS_NORMAL);
            sysLoginMapper.insert(sysLogin);
        }


        // 授权角色
        List<SysRole> rolesList = sysUser.getRoleList();
        if (null == rolesList || rolesList.size() == 0) {
            sysUserRoleMapper.deleteByMap(new HashMap<String, Object>() {{
                put("user_id", sysUser.getUserId());
            }});
        } else {
            List<String> idList = new ArrayList<>();
            for (SysRole role : rolesList) {
                SysUserRole item = new SysUserRole();
                item.setUserId(sysUser.getUserId());
                item.setRoleId(role.getRoleId());

                SysUserRole exists = sysUserRoleMapper.getByUserAndRole(sysUser.getUserId(), role.getRoleId());
                if (null != exists) {
                    item.setId(exists.getId());
                } else {
                    sysUserRoleMapper.insert(item);
                }

                idList.add(item.getId());
            }

            // 去除垃圾数据
            sysUserRoleMapper.deleteNotIn(sysUser.getUserId(), idList);
        }
    }

    @Override
    public List<SysMenu> getMneusByUser(SysUser sysUser) {
        return sysMenuRepo.getMenusByUser(sysUser);
    }

    @Override
    public List<SysUser> getTaPerson(String phone) {
        return baseMapper.getTaPerson(phone);

    }

    @Override
    public SysUser getSysuser(String phone, String tenantId) {
        return baseMapper.getSysuser(phone, tenantId);
    }

    @Override
    public SysUser getSysuserTan(String tenantId) {
        return baseMapper.getSysuserTan(tenantId);
    }

    @Override
    public IPage<FxTenant>  getTenantList(IPage<FxTenant> pg, String phone, QueryWrapper<FxTenant> queryWrapper) {
        return baseMapper.getTenantList(pg, phone,queryWrapper);
    }

}