package com.njyunzhi.admin.service.impl;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.conditions.update.LambdaUpdateChainWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.njyunzhi.admin.service.SysUserService;
import com.njyunzhi.admin.service.TaPersonService;
import com.njyunzhi.repository.BaseServiceImpl;
import com.njyunzhi.repository.entity.SysUser;
import com.njyunzhi.repository.entity.TaPerson;
import com.njyunzhi.repository.mapper.SysUserMapper;
import com.njyunzhi.repository.mapper.TaPersonMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 人员表;(ta_person)表服务实现类
 *
 * @author : http://www.chiner.pro
 * @date : 2024-2-26
 */
@Service
public class TaPersonServiceImpl extends BaseServiceImpl<TaPersonMapper, TaPerson> implements TaPersonService {
    @Autowired
    private TaPersonMapper taPersonMapper;

    /**
     * 通过ID查询单条数据
     *
     * @param personId 主键
     * @return 实例对象
     */
    public TaPerson queryById(String personId) {
        return taPersonMapper.selectById(personId);
    }

    /**
     * 分页查询
     *
     * @param taPerson 筛选条件
     * @param current  当前页码
     * @param size     每页大小
     * @return
     */
    public Page<TaPerson> paginQuery(TaPerson taPerson, long current, long size) {
        //1. 构建动态查询条件
        LambdaQueryWrapper<TaPerson> queryWrapper = new LambdaQueryWrapper<>();
        if (StrUtil.isNotBlank(taPerson.getPersonName())) {
            queryWrapper.eq(TaPerson::getPersonName, taPerson.getPersonName());
        }
        if (StrUtil.isNotBlank(taPerson.getAvatar())) {
            queryWrapper.eq(TaPerson::getAvatar, taPerson.getAvatar());
        }
        if (StrUtil.isNotBlank(taPerson.getPhone())) {
            queryWrapper.eq(TaPerson::getPhone, taPerson.getPhone());
        }
        if (StrUtil.isNotBlank(taPerson.getEmail())) {
            queryWrapper.eq(TaPerson::getEmail, taPerson.getEmail());
        }
        if (StrUtil.isNotBlank(taPerson.getOpenId())) {
            queryWrapper.eq(TaPerson::getOpenId, taPerson.getOpenId());
        }
        if (StrUtil.isNotBlank(taPerson.getCreatedBy())) {
            queryWrapper.eq(TaPerson::getCreatedBy, taPerson.getCreatedBy());
        }
        if (StrUtil.isNotBlank(taPerson.getUpdatedBy())) {
            queryWrapper.eq(TaPerson::getUpdatedBy, taPerson.getUpdatedBy());
        }
        //2. 执行分页查询
        Page<TaPerson> pagin = new Page<>(current, size, true);
        IPage<TaPerson> selectResult = taPersonMapper.selectByPage(pagin, queryWrapper);
        pagin.setPages(selectResult.getPages());
        pagin.setTotal(selectResult.getTotal());
        pagin.setRecords(selectResult.getRecords());
        //3. 返回结果
        return pagin;
    }

    /**
     * 新增数据
     *
     * @param taPerson 实例对象
     * @return 实例对象
     */
    public TaPerson insert(TaPerson taPerson) {
        taPersonMapper.insert(taPerson);
        return taPerson;
    }

    /**
     * 更新数据
     *
     * @param taPerson 实例对象
     * @return 实例对象
     */
    public TaPerson update(TaPerson taPerson) {
        //1. 根据条件动态更新
        LambdaUpdateChainWrapper<TaPerson> chainWrapper = new LambdaUpdateChainWrapper<TaPerson>(taPersonMapper);
        if (StrUtil.isNotBlank(taPerson.getPersonName())) {
            chainWrapper.eq(TaPerson::getPersonName, taPerson.getPersonName());
        }
        if (StrUtil.isNotBlank(taPerson.getAvatar())) {
            chainWrapper.eq(TaPerson::getAvatar, taPerson.getAvatar());
        }
        if (StrUtil.isNotBlank(taPerson.getPhone())) {
            chainWrapper.eq(TaPerson::getPhone, taPerson.getPhone());
        }
        if (StrUtil.isNotBlank(taPerson.getEmail())) {
            chainWrapper.eq(TaPerson::getEmail, taPerson.getEmail());
        }
        if (StrUtil.isNotBlank(taPerson.getOpenId())) {
            chainWrapper.eq(TaPerson::getOpenId, taPerson.getOpenId());
        }
        if (StrUtil.isNotBlank(taPerson.getCreatedBy())) {
            chainWrapper.eq(TaPerson::getCreatedBy, taPerson.getCreatedBy());
        }
        if (StrUtil.isNotBlank(taPerson.getUpdatedBy())) {
            chainWrapper.eq(TaPerson::getUpdatedBy, taPerson.getUpdatedBy());
        }
        //2. 设置主键，并更新
        chainWrapper.set(TaPerson::getPersonId, taPerson.getPersonId());
        boolean ret = chainWrapper.update();
        //3. 更新成功了，查询最最对象返回
        if (ret) {
            return queryById(taPerson.getPersonId());
        } else {
            return taPerson;
        }
    }

    /**
     * 通过主键删除数据
     *
     * @param personId 主键
     * @return 是否成功
     */
    public boolean deleteById(String personId) {
        int total = taPersonMapper.deleteById(personId);
        return total > 0;
    }
}