package com.njyunzhi.common.util;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;
import org.springframework.web.multipart.MultipartFile;

import java.io.File;
import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.nio.file.StandardOpenOption;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;

@Component
public class FileUtil {

    @Value("${yz.upload.path}")
    String uploadPath;

    @Value("${yz.upload.server-prefix}")
    String serverPrefix;

    public String getServerPrefix() {
        return serverPrefix;
    }

    public String getUploadPath() {
        File tmp = new File(uploadPath);
        if (!tmp.exists()) {
            tmp.mkdir();
        }

        return uploadPath;
    }

    public String getMonth() {
        LocalDateTime now = LocalDateTime.now();
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM");
        return now.format(formatter);
    }

    public String encodeFileName(String fname) {
        return fname;
//        if (null == fname) return null;
//
//        int pos = fname.lastIndexOf(".");
//
//        String name = pos > -1 ? fname.substring(0, pos) : fname;
//        String ext = pos > -1 ? fname.substring(pos + 1) : "";
//
//        return StringUtil.encodeURIComponent(name) + "." + ext;
    }

    /**
     * 上传图片
     * @param multipartFile
     * @param fileName
     * @return
     * @throws IOException
     */
    public String saveMultipartFile(MultipartFile multipartFile, String fileName) throws IOException {
        String fName = null == fileName ? multipartFile.getOriginalFilename() : fileName;
        fName = encodeFileName(fName);
        String nfName = String.format("%s/%d-%s", getMonth(), System.currentTimeMillis(), fName);

        // 上传目录以日期分类
        File tmp = new File(String.format("%s/%s", getUploadPath(), getMonth()));
        if (!tmp.exists()) {
            tmp.mkdir();
        }

        File file = new File(String.format("%s/%s", getUploadPath(), nfName));
        multipartFile.transferTo(file);
        String url = String.format("%s/%s", serverPrefix, nfName);
        return url;
    }

    // 保存文件
    public String saveFile(File file, String fileName) throws Exception {
        fileName = encodeFileName(fileName);
        String uploadRootPath = getUploadPath();
        String monthStr = getMonth();

        // 上传目录
        String upPath = String.format("%s/%s", uploadRootPath, monthStr);
        File tmp = new File(upPath);
        if (!tmp.exists()) {
            tmp.mkdir();
        }

        String newFileName = String.format("%d-%s", System.currentTimeMillis(), fileName);
        String newFilePath = String.format("%s/%s", upPath, newFileName);
        if (!file.renameTo(new File(newFilePath))) {
            throw new Exception("保存文件失败");
        };

        // 返回值 去掉根目录
        return String.format("%s/%s", monthStr, newFileName);
    }

    // 保存文件
    public String saveFile(byte[] bytes, String fileName) throws Exception {
        fileName = encodeFileName(fileName);
        String uploadRootPath = getUploadPath();
        String monthStr = getMonth();

        // 上传目录
        String upPath = String.format("%s/%s", uploadRootPath, monthStr);
        File tmp = new File(upPath);
        if (!tmp.exists()) {
            tmp.mkdir();
        }

        String newFileName = String.format("%d-%s", System.currentTimeMillis(), fileName);
        String newFilePath = String.format("%s/%s", upPath, newFileName);

        Files.write(Paths.get(newFilePath), bytes, StandardOpenOption.CREATE);

        // 返回值 去掉根目录
        return String.format("%s/%s", monthStr, newFileName);
    }

    public String transPath(String localPath) {
        if (null == localPath) return null;

        String uploadPath = getUploadPath().replaceAll("\\\\", "/");
        String urlStr = localPath.replaceAll("\\\\", "/").replace(uploadPath, getServerPrefix());

        return urlStr;
    }
}
