package com.njyunzhi.common.util;

import lombok.extern.slf4j.Slf4j;
import net.coobird.thumbnailator.Thumbnails;
import org.springframework.stereotype.Component;

import javax.imageio.ImageIO;
import java.awt.image.BufferedImage;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;

@Slf4j
@Component
public class FileUtilCompression {
    public static InputStream compressMultipartFile(InputStream inputStream, int targetSize) throws IOException {
        BufferedImage image = ImageIO.read(inputStream);
        float quality = 0.6f;
        int originalWidth = image.getWidth();
        int originalHeight = image.getHeight();

        int targetWidth = originalWidth;
        int targetHeight = originalHeight;

        if (originalWidth > targetSize || originalHeight > targetSize) {
            double scaleFactor = Math.min((double) targetSize / originalWidth, (double) targetSize / originalHeight);
            targetWidth = (int) (originalWidth * scaleFactor);
            targetHeight = (int) (originalHeight * scaleFactor);
        }

        BufferedImage resizedImage = Thumbnails.of(image)
                .size(targetWidth, targetHeight)
                .outputQuality(quality)
                .asBufferedImage();

        ByteArrayOutputStream outputStream = new ByteArrayOutputStream();
        ImageIO.write(resizedImage, "jpg", outputStream);

        return new ByteArrayInputStream(outputStream.toByteArray());
    }

    public static byte[] compressSize(byte[] imageBytes, long targetSize, float quality) throws IOException {
        if (imageBytes == null || imageBytes.length <= 0 || imageBytes.length < targetSize) {
            return imageBytes;
        }

        long srcSize = imageBytes.length;
        try {
            ByteArrayInputStream inputStream = new ByteArrayInputStream(imageBytes);
            ByteArrayOutputStream outputStream= new ByteArrayOutputStream(imageBytes.length);
            Thumbnails.of(inputStream).scale(1f).outputQuality(quality).toOutputStream(outputStream);
            imageBytes = outputStream.toByteArray();
            log.info(
                    "【图片压缩】图片原大小={}kb | 压缩后大小={}kb",
                    srcSize / 1024,
                    imageBytes.length / 1024);
        } catch (Exception e) {
            log.error("【图片压缩】msg=图片压缩失败!", e);
        }
        return imageBytes;
    }
}