package com.njyunzhi.common.util;

import com.alibaba.fastjson2.JSON;
import lombok.extern.slf4j.Slf4j;
import okhttp3.*;
import okhttp3.logging.HttpLoggingInterceptor;

import javax.net.ssl.X509TrustManager;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

@Slf4j
public class HttpUtil {

    private static OkHttpClient client = createClient();

    public static OkHttpClient createClient() {
        X509TrustManager manager = SSLSocketClient.getX509TrustManager();
        ConnectionSpec spec = new ConnectionSpec.Builder(ConnectionSpec.MODERN_TLS)
                .tlsVersions(TlsVersion.TLS_1_0, TlsVersion.TLS_1_1, TlsVersion.TLS_1_2)
                .build();
        List<ConnectionSpec> specList = new ArrayList<>();
        specList.add(spec);
        OkHttpClient.Builder builder = new OkHttpClient.Builder()
                .connectionSpecs(specList)
                .sslSocketFactory(SSLSocketClient.getSocketFactory(manager), manager)
                .hostnameVerifier(SSLSocketClient.getHostnameVerifier())
                ;

        HttpLoggingInterceptor.Logger logInterceptor = log::info;
        HttpLoggingInterceptor httpLoggingInterceptor = new HttpLoggingInterceptor(logInterceptor);
        httpLoggingInterceptor.setLevel(HttpLoggingInterceptor.Level.BODY);
        builder.addInterceptor(httpLoggingInterceptor);

        return builder.build();
    }

    public static Request.Builder getRequestBuilder() {
        return new Request.Builder();
    }

    public static HttpUrl buildURL(String url, Map<String, Object> params) {
        HttpUrl.Builder queryUrlBuilder = HttpUrl.get(url).newBuilder();

        if (null != params && !params.isEmpty()) {
            params.forEach((key, value) -> {
                if (null == value || StringUtil.isEmpty(value.toString())) {
                    queryUrlBuilder.addQueryParameter(key, "");
                } else {
                    queryUrlBuilder.addQueryParameter(key, value.toString());
                }
            });
        }

        return queryUrlBuilder.build();
    }

    public static RequestBody buildJSONBody(Object data) {
        if (null == data) {
            return null;
        }

        String jsonString = JSON.toJSONString(data);

        return RequestBody.create(
                jsonString,
                MediaType.parse("application/json") // application/json
        );
    }

    public static Headers buildHeaders(Map<String, Object> headers) {
        Headers.Builder headersBuilder = new Headers.Builder();

        if (null != headers && !headers.isEmpty()) {
            for (Map.Entry<String, Object> entry : headers.entrySet()) {
                headersBuilder.add(entry.getKey(), entry.getValue().toString());
            }
        }

        return headersBuilder.build();
    }


    public static Response request(String url, Map<String, Object> params, Object data, Map<String, Object> headers, String method) throws IOException {
        if (null == method) method = "GET";

        Request.Builder requestBuilder = HttpUtil.getRequestBuilder();
        requestBuilder.url(HttpUtil.buildURL(url, params));
        requestBuilder.headers(buildHeaders(headers));
        requestBuilder.method(method, HttpUtil.buildJSONBody(data));

        Request request = requestBuilder.build();
        return client.newCall(request).execute();
    }

    public static Response get(String url, Map<String, Object> params) throws IOException {
        return request(url, params, null, null, null);
    }

    public static Response post(String url, Object data, Map<String, Object> params) throws IOException {
        return request(url, params, data, null, "POST");
    }

    public static String download(String url, String fileName, FileUtil fileUtil) throws Exception {
        Request.Builder requestBuilder = getRequestBuilder();
        requestBuilder.url(url);

        Request request = requestBuilder.build();
        Response response = client.newCall(request).execute();
        ResponseBody responseBody = response.body();
        byte[] bytes = responseBody.bytes();

        return fileUtil.saveFile(bytes, fileName);
    }
}
