package com.njyunzhi.platform.controller;

import cn.dev33.satoken.stp.StpUtil;
import cn.dev33.satoken.util.SaResult;
import com.njyunzhi.common.util.StringUtil;
import com.njyunzhi.platform.dto.ChangePasswordDTO;
import com.njyunzhi.platform.dto.LoginDTO;
import com.njyunzhi.platform.service.FxLoginService;
import com.njyunzhi.repository.BaseController;
import com.njyunzhi.repository.entity.FxUser;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.Map;

 /**
 * 登录信息表;(fx_login)表控制层
 * @author : http://njyunzhi.com
 * @date : 2023-10-25
 */
@Api(tags = "登录信息表对象功能接口")
@RestController
@RequestMapping("/")
public class FxLoginController extends BaseController {
    
    @Autowired
    private FxLoginService fxLoginService;

     @PostMapping("/login")
     @ApiOperation(value="后台登录", notes = "后台登录", httpMethod = "POST", response = SaResult.class)
     public SaResult login(@ApiParam("登录参数") @RequestBody LoginDTO loginParm) throws Exception {

         if (StringUtil.isEmpty(loginParm.getLoginName()) || StringUtil.isEmpty(loginParm.getPassword())) {
             return SaResult.error("登录用户或者密码不能为空");
         }

         FxUser fxUser = fxLoginService.login(loginParm);

         StpUtil.login(fxUser.getUserId());
         String tokenValue = StpUtil.getTokenValue();

         Map<String, Object> result = new HashMap<>();
         result.put("user", fxUser);
         result.put("token", tokenValue);

         return SaResult.data(result);
     }

     @PostMapping("/logout")
     @ApiOperation(value="登出", notes = "登出", httpMethod = "POST", response = SaResult.class)
     public SaResult logout() throws Exception {
         FxUser fxUser = (FxUser) currentUser();
         StpUtil.logout(fxUser.getUserId());
         return SaResult.ok();
     }

     @PutMapping("/change-password")
     @ApiOperation(value="修改密码", notes = "修改密码", httpMethod = "PUT", response = SaResult.class)
     public SaResult changePassword(@ApiParam("修改密码参数") @RequestBody ChangePasswordDTO param) throws Exception {
         if (StringUtil.isEmpty(param.getOriginPassword()) || StringUtil.isEmpty(param.getNewPassword())) {
             return SaResult.error("原始密码或新密码不能为空");
         }

         FxUser fxUser = (FxUser) currentUser();

         boolean isOk = fxLoginService.changePassword(fxUser, param);
         if (!isOk) {
             SaResult.error("修改失败, 请重试");
         }

         return SaResult.ok("密码修改成功");
     }
 }