package com.njyunzhi.platform.controller;

import cn.dev33.satoken.util.SaResult;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.njyunzhi.common.util.StringUtil;
import com.njyunzhi.framework.accesslimit.AccessLimit;
import com.njyunzhi.framework.log.OpLog;
import com.njyunzhi.platform.service.FxMenuService;
import com.njyunzhi.repository.BaseController;
import com.njyunzhi.repository.entity.FxMenu;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

 /**
 * 菜单表;(fx_menu)表控制层
 * @author : http://njyunzhi.com
 * @date : 2023-10-25
 */
@Api(tags = "菜单表对象功能接口")
@RestController
@RequestMapping("/")
public class FxMenuController extends BaseController {
    
    @Autowired
    private FxMenuService fxMenuService;
    
    /** 
     * 通过ID查询单条数据 
     *
     * @param id 主键
     * @return 实例对象
     */
    @OpLog(module = "菜单表", action = "查询单条数据", desc = "ID：{{#id}}")
    @AccessLimit()
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/fxMenu/{id}")
    public SaResult queryById(@ApiParam("对象ID") @PathVariable String id) throws Exception {
        return SaResult.data(fxMenuService.getById(id));
    }
    
    /** 
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @OpLog(module = "菜单表", action = "分页列表查询")
    @AccessLimit()
    @ApiOperation("分页查询")
    @GetMapping("/fxMenu")
    public SaResult list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                            @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                            @ApiParam("正序排列") @RequestParam(value ="sortAsc", required = false) String sortAsc,
                         @ApiParam("倒序排列") @RequestParam(value ="sortDesc", defaultValue = "created_at") String sortDesc) throws Exception {
        
        IPage<FxMenu> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<FxMenu> queryWrapper = new QueryWrapper<>();
        queryWrapper.orderByAsc(StringUtil.isNotEmpty(sortAsc), StringUtil.humpToLine(sortAsc));
        queryWrapper.orderByDesc(StringUtil.isNotEmpty(sortDesc), StringUtil.humpToLine(sortDesc));
        IPage<FxMenu> result = fxMenuService.page(pg, queryWrapper);
        
        return SaResult.data(result);
    }
    
    /** 
     * 新增数据
     *
     * @param fxMenu 实例对象
     * @return 实例对象
     */
    @OpLog(module = "菜单表", action = "新增数据")
    @AccessLimit()
    @ApiOperation("新增数据")
    @PostMapping("/fxMenu")
    public SaResult add(@ApiParam("对象实体") @Validated @RequestBody FxMenu fxMenu) throws Exception {
        fxMenuService.save(fxMenu);
        return SaResult.data(fxMenu);
    }
    
    /** 
     * 更新数据
     *
     * @param fxMenu 实例对象
     * @return 实例对象
     */
    @OpLog(module = "菜单表", action = "更新数据")
    @AccessLimit()
    @ApiOperation("更新数据")
    @PutMapping("/fxMenu/{id}")
    public SaResult edit(@ApiParam("对象实体") @Validated @RequestBody FxMenu fxMenu,
                            @ApiParam("对象ID") @PathVariable String id ) throws Exception {
        fxMenuService.updateById(fxMenu);
        return SaResult.data(fxMenu);
    }
    
    /** 
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @OpLog(module = "菜单表", action = "删除数据", desc = "ID：{{#id}}")
    @AccessLimit()
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/fxMenu/{id}")
    public SaResult deleteById(@ApiParam("对象ID") @PathVariable String id){
        fxMenuService.removeById(id);
        return SaResult.data("success");
    }
}