package com.njyunzhi.platform.controller;

import cn.dev33.satoken.stp.StpUtil;
import cn.dev33.satoken.util.SaResult;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.njyunzhi.common.util.StringUtil;
import com.njyunzhi.framework.accesslimit.AccessLimit;
import com.njyunzhi.framework.log.OpLog;
import com.njyunzhi.platform.service.FxUserService;
import com.njyunzhi.repository.BaseController;
import com.njyunzhi.repository.entity.FxUser;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.Map;

/**
 * 用户表;(fx_user)表控制层
 *
 * @author : http://njyunzhi.com
 * @date : 2023-10-25
 */
@Api(tags = "用户表对象功能接口")
@RestController
@RequestMapping("/")
public class FxUserController extends BaseController {

    @Autowired
    private FxUserService fxUserService;


    @AccessLimit()
    @ApiOperation("获取当前用户")
    @GetMapping("/current")
    public SaResult getCurrentUser() throws Exception {
        boolean isLogin = StpUtil.isLogin();
        if (!isLogin) {
            return SaResult.error("请先登录系统");
        }

        Map<String, Object> result = new HashMap<>();
        FxUser fxUser = (FxUser) currentUser();
//         List<FxMenu> menuList = fxUserService.getMenusByUser(fxUser);
//         List<FxMenuButton> buttonList = fxUserService.getMenuButtonsByUser(fxUser);

        result.put("user", fxUser);
//         result.put("menuList", menuList);
//         result.put("buttonList", buttonList);
        return SaResult.data(result);
    }

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @OpLog(module = "用户表", action = "查询单条数据", desc = "ID：{{#id}}")
    @AccessLimit()
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/fxUser/{id}")
    public SaResult queryById(@ApiParam("对象ID") @PathVariable String id) throws Exception {
        return SaResult.data(fxUserService.getById(id));
    }

    /**
     * 分页查询
     *
     * @param pageNum  当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @OpLog(module = "用户表", action = "分页列表查询")
    @AccessLimit()
    @ApiOperation("分页查询")
    @GetMapping("/fxUser")
    public SaResult list(@ApiParam("页码") @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                         @ApiParam("单页数据量") @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                         @ApiParam("正序排列") @RequestParam(value = "sortAsc", required = false) String sortAsc,
                         @ApiParam("倒序排列") @RequestParam(value = "sortDesc", defaultValue = "created_at") String sortDesc,
                         @ApiParam("用户名") @RequestParam(value = "userName", required = false) String userName,
                         @ApiParam("手机号") @RequestParam(value = "phone", required = false) String phone

    ) throws Exception {

        IPage<FxUser> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<FxUser> queryWrapper = new QueryWrapper<>();
        queryWrapper.like(!StringUtil.isEmpty(userName), "user_name", userName);
        queryWrapper.like(!StringUtil.isEmpty(phone), "phone", phone);
        queryWrapper.orderByAsc(StringUtil.isNotEmpty(sortAsc), StringUtil.humpToLine(sortAsc));
        queryWrapper.orderByDesc(StringUtil.isNotEmpty(sortDesc), StringUtil.humpToLine(sortDesc));
        IPage<FxUser> result = fxUserService.page(pg, queryWrapper);
        return SaResult.data(result);
    }

    /**
     * 新增数据
     *
     * @param fxUser 实例对象
     * @return 实例对象
     */
    @OpLog(module = "用户表", action = "新增数据")
    @AccessLimit()
    @ApiOperation("新增数据")
    @PostMapping("/fxUser")
    public SaResult add(@ApiParam("对象实体") @Validated @RequestBody FxUser fxUser) throws Exception {
        fxUserService.save(fxUser);
        return SaResult.data(fxUser);
    }

    /**
     * 新增数据
     *
     * @param fxUser& fxLogin 实例对象
     */
    @OpLog(module = "用户表", action = "新增数据")
    @AccessLimit()
    @ApiOperation("新增数据")
    @PostMapping("/fxUserLogin")
    public SaResult adds(@ApiParam("对象实体") @Validated @RequestBody FxUser fxUser) throws Exception {
        if (null == fxUser.getUserId()) {
            long count = fxUserService.countBy("phone", fxUser.getPhone());
            if (count > 0) {
                return SaResult.error("手机号码已存在");
            }
        }

        fxUserService.mergeData(fxUser);

        return SaResult.data(fxUserService.getById(fxUser.getUserId()));
    }


    /**
     * 更新数据
     *
     * @param fxUser 实例对象
     * @return 实例对象
     */
    @OpLog(module = "用户表", action = "更新数据")
    @AccessLimit()
    @ApiOperation("更新数据")
    @PutMapping("/fxUser/{id}")
    public SaResult edit(@ApiParam("对象实体") @Validated @RequestBody FxUser fxUser,
                         @ApiParam("对象ID") @PathVariable String id) throws Exception {
        fxUserService.updateById(fxUser);
        return SaResult.data(fxUser);
    }


    /**
     * 更新数据
     *
     * @param fxUser& fxLogin 实例对象
     * @return 实例对象
     */
    @OpLog(module = "用户表", action = "更新数据")
    @AccessLimit()
    @ApiOperation("更新数据")
    @PutMapping("/fxUserLogin/{userId}")
    public SaResult updateEdit(@ApiParam("对象实体") @Validated @RequestBody FxUser fxUser,
                               @ApiParam("对象ID") @PathVariable String userId) throws Exception {
        fxUser.setUserId(userId);
        fxUserService.updateById(fxUser);
        return SaResult.data(fxUser);
    }


    /**
     * 通过主键删除数据
     *
     * @param userId  主键
     * @param fxUser& fxLogin 实例对象
     * @return 是否成功
     */
    @OpLog(module = "用户表", action = "删除数据", desc = "ID：{{#id}}")
    @AccessLimit()
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/fxUserLogin/{userId}")
    public SaResult deleteByIds(@ApiParam("对象ID") @PathVariable String userId) {
        fxUserService.removeUserLoginById(userId);
        return SaResult.data("success");
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @OpLog(module = "用户表", action = "删除数据", desc = "ID：{{#id}}")
    @AccessLimit()
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/fxUser/{id}")
    public SaResult deleteById(@ApiParam("对象ID") @PathVariable String id) {
        fxUserService.removeById(id);
        return SaResult.data("success");
    }
}