package com.njyunzhi.platform.service.impl;

import com.njyunzhi.common.util.EncryptUtil;
import com.njyunzhi.common.util.StringUtil;
import com.njyunzhi.platform.common.Constants;
import com.njyunzhi.platform.dto.ChangePasswordDTO;
import com.njyunzhi.platform.dto.LoginDTO;
import com.njyunzhi.platform.service.FxLoginService;
import com.njyunzhi.repository.BaseServiceImpl;
import com.njyunzhi.repository.entity.FxLogin;
import com.njyunzhi.repository.entity.FxUser;
import com.njyunzhi.repository.mapper.FxLoginMapper;
import com.njyunzhi.repository.mapper.FxUserMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 登录信息表;(fx_login)表服务实现类
 *
 * @author : http://www.chiner.pro
 * @date : 2023-10-25
 */
@Service
public class FxLoginServiceImpl extends BaseServiceImpl<FxLoginMapper, FxLogin> implements FxLoginService {

    @Autowired
    FxUserMapper fxUserMapper;

    boolean checkPassword(String src, String targ, String salt) {
        String newPass = EncryptUtil.md5(src, salt);
        return targ.equals(newPass);
    }

    @Override
    public FxUser login(LoginDTO loginParm) throws Exception {
        String loginType = loginParm.getLoginType();
        if(loginParm.getLoginType()==null){
            loginType=Constants.LOGIN_TYPE;
        }
        FxLogin fxLogin = baseMapper.getInfoBy(loginType, loginParm.getLoginName());
        if (null == fxLogin) {
            throw new Exception("用户名或者密码不正确");
        }

//        CaptchaDTO captcha = loginParm.getCaptcha();
//        if (null == captcha) {
//            throw new Exception("验证码不正确");
//        }
//
//        boolean isOk = CaptchaTool.validate(captcha.getId(), captcha.getValue());
//        if (!isOk) {
//            throw new Exception("验证码不正确");
//        } else {
//            CaptchaTool.remove(captcha.getId());
//        }

        String userId = fxLogin.getUserId();
        if (StringUtil.isEmpty(userId)) {
            throw new Exception("用户名或者密码不正确");
        }

        boolean isRight = checkPassword(loginParm.getPassword(), fxLogin.getPassword(), userId);
        if (!isRight) {
            throw new Exception("用户名或者密码不正确");
        }

        FxUser user = fxUserMapper.selectById(userId);
        if (null == user) {
            throw new Exception("用户名或者密码不正确");
        }

        if (Constants.STATUS_NORMAL != user.getStatus()) {
            throw new Exception("用户状态异常, 请联系管理员");
        }

        return user;
    }

    @Override
    public boolean changePassword(FxUser user, ChangePasswordDTO param) throws Exception {
        String passwordEncrypted = EncryptUtil.md5(param.getOriginPassword(), user.getUserId());
        Long cnt = baseMapper.countByUserAndPassword(user.getUserId(), passwordEncrypted);

        if (null == cnt || cnt < 1) {
            throw new Exception("原始密码不正确");
        }

        String newPassword = EncryptUtil.md5(param.getNewPassword(), user.getUserId());
        return baseMapper.updateUserPassword(user.getUserId(), newPassword) > 0;
    }
}