package com.njyunzhi.platform.service.impl;

import com.njyunzhi.common.util.EncryptUtil;
import com.njyunzhi.common.util.StringUtil;
import com.njyunzhi.platform.common.Constants;
import com.njyunzhi.platform.service.FxTenantService;
import com.njyunzhi.repository.BaseServiceImpl;
import com.njyunzhi.repository.entity.FxTenant;
import com.njyunzhi.repository.entity.SysDept;
import com.njyunzhi.repository.entity.SysLogin;
import com.njyunzhi.repository.entity.SysUser;
import com.njyunzhi.repository.mapper.FxTenantMapper;
import com.njyunzhi.repository.mapper.SysDeptMapper;
import com.njyunzhi.repository.mapper.SysLoginMapper;
import com.njyunzhi.repository.mapper.SysUserMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.HashMap;
import java.util.Map;

/**
 * 租户表;(fx_tenant)表服务实现类
 *
 * @author : http://www.chiner.pro
 * @date : 2023-10-25
 */
@Service
public class FxTenantServiceImpl extends BaseServiceImpl<FxTenantMapper, FxTenant> implements FxTenantService {

    @Autowired
    SysDeptMapper sysDeptMapper;

    @Autowired
    SysUserMapper sysUserMapper;

    @Autowired
    SysLoginMapper sysLoginMapper;

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void createNew(FxTenant fxTenant) {
        String tenantId = StringUtil.UUID();
        String deptId = StringUtil.UUID();
        String userId = StringUtil.UUID();
        String loginId = StringUtil.UUID();
        String roleId = StringUtil.UUID();

        if (null == fxTenant.getStatus()) {
            fxTenant.setStatus(Constants.STATUS_READY);
        }

        fxTenant.setTenantId(tenantId);
        fxTenant.setLoginId(loginId);

        // 保存入库
        save(fxTenant);

        // 创建租户机构
        SysDept sysDept = new SysDept();
        sysDept.setDeptId(deptId);
        sysDept.setDeptCode("100");
        sysDept.setDeptName(fxTenant.getTenantName());
        sysDept.setParentId(Constants.ROOT_TREE);
        sysDept.setSortNo(1);
        sysDept.setStatus(Constants.STATUS_NORMAL);
        sysDept.setTenantId(tenantId);
        sysDept.setTenantName(fxTenant.getTenantName());
        sysDept.setCreatedBy(userId);
        sysDeptMapper.insert(sysDept);

        // 创建租户账户
        SysUser sysUser = new SysUser();
        sysUser.setUserId(userId);
        sysUser.setUserName(fxTenant.getManager());
        sysUser.setPhone(fxTenant.getPhone());
        sysUser.setDeptId(deptId);
        sysUser.setIsAdmin(1);
        sysUser.setStatus(Constants.STATUS_NORMAL);
        sysUser.setTenantId(tenantId);
        sysUser.setCreatedBy(userId);
        sysUserMapper.insert(sysUser);

        // 创建登录信息
        SysLogin sysLogin = new SysLogin();
        sysLogin.setLoginId(loginId);
        sysLogin.setUserId(userId);
        sysLogin.setLoginType("admin.pc");
        sysLogin.setLoginName(fxTenant.getPhone());
        sysLogin.setPassword(EncryptUtil.md5(EncryptUtil.md5("123456"), userId));
        sysLogin.setStatus(fxTenant.getStatus());
        sysLogin.setTenantId(tenantId);
        sysLogin.setCreatedBy(userId);
        sysLoginMapper.insert(sysLogin);

    }

    @Override
    public void removeSysFxById(String id) {
        baseMapper.removeSysFxById(id);
    }

    @Override
    public void upDateNew(FxTenant fxTenant) {
        String tenantId = fxTenant.getTenantId();
        String userId = fxTenant.getCreatedBy();
        String loginId = fxTenant.getLoginId();
        String tenantName = fxTenant.getTenantName();
        String phone = fxTenant.getPhone();
        String manager = fxTenant.getManager();


        //更新租户机构
   sysDeptMapper.updateDept(tenantId, tenantName);

        Map<String, Object> params = new HashMap<>();
        //        sysUser的

        params.put("tenantId", tenantId);
        params.put("phone", phone);
        params.put("manager", manager);
//        SySLogin
        params.put("loginId", loginId);
        params.put("loginName", phone);
        params.put("deleted",fxTenant.getDeleted());

//更新
      sysUserMapper.updateUser(params);


//        Map<String, Object> paramsLogin = new HashMap<>();
//        params.put("loginId", loginId);
//        params.put("loginName", phone);

        sysLoginMapper.updateLogin(params);


    }
}